
Namespace DirectoryServices

  ''' <summary>
  ''' User's Active Directory Info
  ''' </summary>
  ''' <remarks></remarks>
  Public Structure UserInfo
    Private _contactName As String
    ''' <summary>
    ''' Account Contact Name
    ''' </summary>
    ''' <value></value>
    ''' <returns>String</returns>
    ''' <remarks></remarks>
    Public Property ContactName() As String
      Get
        Return _contactName
      End Get
      Set(ByVal value As String)
        _contactName = value
      End Set
    End Property
    Private _email As String
    ''' <summary>
    ''' Account Email Address
    ''' </summary>
    ''' <value></value>
    ''' <returns>String</returns>
    ''' <remarks></remarks>
    Public Property Email() As String
      Get
        Return _email
      End Get
      Set(ByVal value As String)
        _email = value
      End Set
    End Property
    Private _department As String
    ''' <summary>
    ''' Account Department Name
    ''' </summary>
    ''' <value></value>
    ''' <returns>String</returns>
    ''' <remarks></remarks>
    Public Property Department() As String
      Get
        Return _department
      End Get
      Set(ByVal value As String)
        _department = value
      End Set
    End Property
    Private _manager As String
    ''' <summary>
    ''' Account Managers' Name
    ''' </summary>
    ''' <value></value>
    ''' <returns>String</returns>
    ''' <remarks></remarks>
    Public Property Manager() As String
      Get
        Return _manager
      End Get
      Set(ByVal value As String)
        _manager = value
      End Set
    End Property
    Private _telephone As String
    ''' <summary>
    ''' Contacts telephone number.
    ''' </summary>
    ''' <value>String</value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Telephone() As String
      Get
        Return _telephone
      End Get
      Set(ByVal value As String)
        _telephone = value
      End Set
    End Property
    Private _title As String
    ''' <summary>
    ''' Contacts Title
    ''' </summary>
    ''' <value></value>
    ''' <returns>String</returns>
    ''' <remarks></remarks>
    Public Property Title() As String
      Get
        Return _title
      End Get
      Set(ByVal value As String)
        _title = value
      End Set
    End Property
    Private _fax As String
    ''' <summary>
    ''' Users fax number.
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Fax() As String
      Get
        Return _fax
      End Get
      Set(ByVal value As String)
        _fax = value
      End Set
    End Property

    Private _firstName As String
    ''' <summary>
    ''' Users first name
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property FirstName() As String
      Get
        Return _firstName
      End Get
      Set(ByVal value As String)
        _firstName = value
      End Set
    End Property
    Private _lastName As String
    ''' <summary>
    ''' Users last name.
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property LastName() As String
      Get
        Return _lastName
      End Get
      Set(ByVal value As String)
        _lastName = value
      End Set
    End Property
    Private _deliveryOffice As String
    ''' <summary>
    ''' Users delivery office
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property DeliveryOffice() As String
      Get
        Return _deliveryOffice
      End Get
      Set(ByVal value As String)
        _deliveryOffice = value
      End Set
    End Property

    Public Overrides Function ToString() As String
      Return Me.ContactName
    End Function

  End Structure



  ''' <summary>
  ''' Active Directory Helper Class
  ''' </summary>
  ''' <remarks></remarks>
  Public NotInheritable Class ActiveDirectoryHelper
    Private Const STR_AccountFilter As String = "(SAMAccountName={0})"
    Private Const STR_ContactDepartment As String = "department"
    Private Const STR_ContactEmail As String = "mail"
    Private Const STR_ContactManager As String = "manager"
    Private Const STR_ContactName As String = "cn"
    Private Const STR_ContactNameFilter As String = "(CN={0})"
    Private Const STR_LDAPPrefix As String = "LDAP://"
    Private Const STR_Member As String = "member"
    Private Const STR_SAMAccountName As String = "SAMAccountName"
    Private Const STR_ContactTelephone As String = "telephoneNumber"
    Private Const STR_ContactTitle As String = "title"
    Private Const STR_ContactFirstName As String = "givenName"
    Private Const STR_ContactLastName As String = "sn"
    Private Const STR_ContactFax As String = "facsimileTelephoneNumber"
    Private Const STR_ContactDeliveryOffice As String = "physicalDeliveryOfficeName"


    ''' <summary>
    ''' Retrieves the users Active Directory Contact Name.
    ''' </summary>
    ''' <param name="accountName">Account Name</param>
    ''' <returns>String</returns>
    ''' <remarks></remarks>
    Public Shared Function UserContactName(ByVal accountName As String) As String
      Dim contactName As String = String.Empty

      contactName = UserInfo(accountName).ContactName

      Return contactName

    End Function

    ''' <summary>
    ''' Retrieves the users Active Directory E-Mail address
    ''' </summary>
    ''' <param name="accountName">Account Name</param>
    ''' <returns>String</returns>
    ''' <remarks></remarks>
    Public Shared Function UserEmail(ByVal accountName As String) As String
      Dim emailAddress As String = String.Empty

      emailAddress = UserInfo(accountName).Email

      Return emailAddress

    End Function

    ''' <summary>
    ''' Retrieves the users Active Directory information.
    ''' </summary>
    ''' <param name="accountName">Account Name</param>
    ''' <returns>UserInfo</returns>
    ''' <remarks></remarks>
    Public Shared Function UserInfo(ByVal accountName As String) As UserInfo

      ExtractUserName(accountName)


      Dim info As New UserInfo

      Using searcher As New System.DirectoryServices.DirectorySearcher
        searcher.Filter = String.Format(CultureInfo.CurrentCulture, STR_AccountFilter, accountName)
        searcher.PropertiesToLoad.Add(STR_ContactName)
        searcher.PropertiesToLoad.Add(STR_ContactEmail)
        searcher.PropertiesToLoad.Add(STR_ContactDepartment)
        searcher.PropertiesToLoad.Add(STR_ContactManager)
        searcher.PropertiesToLoad.Add(STR_ContactTelephone)
        searcher.PropertiesToLoad.Add(STR_ContactTitle)
        searcher.PropertiesToLoad.Add(STR_ContactFirstName)
        searcher.PropertiesToLoad.Add(STR_ContactLastName)
        searcher.PropertiesToLoad.Add(STR_ContactFax)
        searcher.PropertiesToLoad.Add(STR_ContactDeliveryOffice)

        Dim result As System.DirectoryServices.SearchResult = searcher.FindOne

        If Not IsNothing(result) Then

          info.ContactName = ExtractPropertyValue(STR_ContactName, result)
          info.Email = ExtractPropertyValue(STR_ContactEmail, result)
          info.Department = ExtractPropertyValue(STR_ContactDepartment, result)
          info.Manager = GetManagerName(ExtractPropertyValue(STR_ContactManager, result))
          info.Telephone = ExtractPropertyValue(STR_ContactTelephone, result)
          info.Title = ExtractPropertyValue(STR_ContactTitle, result)
          info.FirstName = ExtractPropertyValue(STR_ContactFirstName, result)
          info.LastName = ExtractPropertyValue(STR_ContactLastName, result)
          info.Fax = ExtractPropertyValue(STR_ContactFax, result)
          info.DeliveryOffice = ExtractPropertyValue(STR_ContactDeliveryOffice, result)

        End If

      End Using

      Return info

    End Function

    ''' <summary>
    ''' Loads all the users in the current domain.
    ''' </summary>
    ''' <returns>List of <see cref="System.Collections.ObjectModel.ReadOnlyCollection(Of UserInfo)"></see></returns>
    ''' <remarks></remarks>
    Public Shared Function LoadAllUsers() As System.Collections.ObjectModel.ReadOnlyCollection(Of UserInfo)

      Dim users As New System.Collections.Generic.List(Of UserInfo)

      Using searcher As New System.DirectoryServices.DirectorySearcher
        searcher.Filter = "(&(objectClass=Person)(objectClass=User)(!objectClass=computer))"
        searcher.Sort.Direction = System.DirectoryServices.SortDirection.Ascending
        searcher.Sort.PropertyName = STR_ContactName
        'Load Properties that we want
        searcher.PropertiesToLoad.Add(STR_ContactName)
        searcher.PropertiesToLoad.Add(STR_ContactEmail)
        searcher.PropertiesToLoad.Add(STR_ContactDepartment)
        searcher.PropertiesToLoad.Add(STR_ContactManager)
        searcher.PropertiesToLoad.Add(STR_ContactTelephone)
        searcher.PropertiesToLoad.Add(STR_ContactTitle)
        searcher.PropertiesToLoad.Add(STR_ContactFirstName)
        searcher.PropertiesToLoad.Add(STR_ContactLastName)
        searcher.PropertiesToLoad.Add(STR_ContactFax)
        searcher.PropertiesToLoad.Add(STR_ContactDeliveryOffice)

        Dim results As System.DirectoryServices.SearchResultCollection = searcher.FindAll

        If Not IsNothing(results) AndAlso results.Count > 0 Then

          For Each result As System.DirectoryServices.SearchResult In results
            Dim info As New UserInfo

            info.ContactName = ExtractPropertyValue(STR_ContactName, result)
            info.Email = ExtractPropertyValue(STR_ContactEmail, result)
            info.Department = ExtractPropertyValue(STR_ContactDepartment, result)
            info.Manager = GetManagerName(ExtractPropertyValue(STR_ContactManager, result))
            info.Telephone = ExtractPropertyValue(STR_ContactTelephone, result)
            info.Title = ExtractPropertyValue(STR_ContactTitle, result)
            info.FirstName = ExtractPropertyValue(STR_ContactFirstName, result)
            info.LastName = ExtractPropertyValue(STR_ContactLastName, result)
            info.Fax = ExtractPropertyValue(STR_ContactFax, result)
            info.DeliveryOffice = ExtractPropertyValue(STR_ContactDeliveryOffice, result)

            users.Add(info)

          Next

        End If

      End Using

      Return New System.Collections.ObjectModel.ReadOnlyCollection(Of UserInfo)(users)

    End Function

    ''' <summary>
    ''' Validates an Active Directory Account Name
    ''' </summary>
    ''' <param name="accountName">Account Name</param>
    ''' <returns>True if Account Name is active in the current domain.</returns>
    ''' <remarks></remarks>
    Public Shared Function ValidateAccountName(ByVal accountName As String) As Boolean

      ExtractUserName(accountName)

      Dim valid As Boolean = False

      Using searcher As New System.DirectoryServices.DirectorySearcher
        searcher.Filter = String.Format(CultureInfo.CurrentCulture, STR_AccountFilter, accountName)

        Dim result As System.DirectoryServices.SearchResult = searcher.FindOne

        If Not IsNothing(result) Then
          valid = True
        End If

      End Using

      Return valid

    End Function

    ''' <summary>
    ''' Verifies the current user in belongs to the given Active Directory group
    ''' </summary>
    ''' <param name="group">Group name</param>
    ''' <returns>True if in group</returns>
    ''' <remarks></remarks>
    Public Overloads Shared Function IsUserInGroup(ByVal group As String) As Boolean

      If ApplicationHelper.IsAspNet Then
        Return System.Web.HttpContext.Current.User.IsInRole(group)
      Else
        Return My.User.IsInRole(group)
      End If

    End Function

    ''' <summary>
    ''' Verifies the Active Directory Account Name belongs to one of the given groups.
    ''' </summary>
    ''' <param name="accountName">Account Name</param>
    ''' <param name="groups">Group(s)</param>
    ''' <returns>True if the Account Name belongs to at least one group.</returns>
    ''' <remarks></remarks>
    Public Overloads Shared Function IsUserInGroup(ByVal accountName As String, ByVal ParamArray groups As String()) As Boolean

      If String.IsNullOrEmpty(accountName) Then
        Throw New ArgumentNullException("accountName")
      End If

      If Not Collections.ArrayHelper.IsValidArray(groups) Then
        Throw New ArgumentNullException("groups")
      End If

      ExtractUserName(accountName)

      Using searcher As System.DirectoryServices.DirectorySearcher = New System.DirectoryServices.DirectorySearcher()

        For Each groupName As String In groups

          searcher.Filter = String.Format(CultureInfo.CurrentCulture, STR_ContactNameFilter, groupName)

          Using results As System.DirectoryServices.SearchResultCollection = searcher.FindAll()

            For Each result As System.DirectoryServices.SearchResult In results

              Dim resultProperties As System.DirectoryServices.ResultPropertyCollection = result.Properties

              For Each members As Object In resultProperties(STR_Member)

                Using memberEntry As System.DirectoryServices.DirectoryEntry = New System.DirectoryServices.DirectoryEntry(STR_LDAPPrefix + members.ToString)

                  Dim userProperties As System.DirectoryServices.PropertyCollection = memberEntry.Properties

                  Dim tempAccountName As Object = userProperties(STR_SAMAccountName).Value
                  'Validate if user in the group
                  If accountName.ToString = tempAccountName.ToString Then
                    Return True
                  End If

                End Using

              Next

            Next

          End Using

        Next

      End Using

      Return False

    End Function

    ''' <summary>
    ''' Verifies the Active Directory Account Name belongs to the given groups.
    ''' </summary>
    ''' <param name="accountName">Account Name</param>
    ''' <param name="groupName">Group name</param>
    ''' <returns>True if the Account Name belongs to the group</returns>
    ''' <remarks></remarks>
    Public Overloads Shared Function IsUserInGroup(ByVal accountName As String, ByVal groupName As String) As Boolean
      Return IsUserInGroup(accountName, New String() {groupName})
    End Function

    Private Shared Sub ExtractUserName(ByRef accountName As String)
      If accountName.Contains(Constants.CharacterBackSlash) Then
        'Strip off name
        Dim startPosition As Int32 = accountName.LastIndexOf(Constants.CharacterBackSlash) + 1
        accountName = accountName.Substring(startPosition, accountName.Length - startPosition).Trim
      End If
    End Sub

    Private Shared Function ExtractPropertyValue(ByVal propertyName As String, ByVal result As System.DirectoryServices.SearchResult) As String

      Dim propertyValue As String = String.Empty

      If result.Properties.Contains(propertyName) Then
        propertyValue = result.Properties(propertyName).Item(0).ToString()
      End If

      Return propertyValue

    End Function

    Private Shared Function GetManagerName(ByVal name As String) As String

      Dim managerName As String = String.Empty

      If Not String.IsNullOrEmpty(name) Then

        If name.Split(Constants.CharacterComma).Length > 0 Then
          managerName = name.Split(Constants.CharacterComma)(0).Remove(0, 3)
        End If
      End If

      Return managerName

    End Function

    Private Sub New()
    End Sub

  End Class
End Namespace